@@ -141,6 +141,7 @@ def delete_function(function_name, confirm=True):
 
 
 def create_function_from_folder(
+    human_readable_name,
     function_name, 
     folder, 
     handler_path,  
@@ -150,10 +151,11 @@ def create_function_from_folder(
 ):
     """
     Create a Cognite function from a folder. Any existing function with the same
-    name is deleted first.
+    external id is deleted first.
 
     Inputs:
-      - function_name: name of the function to create
+      - human_readable_name: name of function to create
+      - function_name: external id of function to create
       - folder: path where the source code is located
       - handler_path: path to the handler file
       - description: (string) function documentation
@@ -163,12 +165,12 @@ def create_function_from_folder(
     client = global_client["functions"]
     try:
         client.functions.delete(external_id=function_name)
-        logging.debug(f"Deleted function {function_name}")
+        logging.debug(f"Deleted function {human_readable_name} with external id {function_name}")
     except CogniteNotFoundError:
         pass
     
     function = client.functions.create( 
-        name=function_name, 
+        name=human_readable_name, 
         folder=folder, 
         function_path=handler_path,
         external_id=function_name,
@@ -178,13 +180,14 @@ def create_function_from_folder(
         env_vars=env_vars
     )
     logging.debug(
-        f"Created {function_name}: {folder=}, {handler_path=}, {env_vars=}"
+        f"Created function {human_readable_name} with external id {function_name}: {folder=}, {handler_path=}, {env_vars=}"
     )
 
     return function
 
 
 def create_function_from_file(
+    human_readable_name,
     function_name, 
     file_id, 
     description,
@@ -196,17 +199,18 @@ def create_function_from_file(
     exception if there's an existing function with the same name.
 
     Inputs:
-      - function_name: (string) name of the function to create
+      - human_readable_name (str): name of the function to create
+      - function_name: (str) external id of the function to create
       - file_id: (int) the id for the function file in CDF Files
-      - description: (string) function documentation
-      - owner: (string) the function's owner's email
+      - description: (str) function documentation
+      - owner: (str) the function's owner's email
       - secrets: (optional) api keys or similar that should be passed to the
         function
     """
     client = global_client["functions"]
     
     function = client.functions.create( 
-        name=function_name, 
+        name=human_readable_name, 
         file_id=file_id,
         external_id=function_name,
         description=description,
@@ -215,7 +219,7 @@ def create_function_from_file(
         env_vars=env_vars
     )
     logging.debug(
-        f"Created {function_name}: {file_id=}, {env_vars=}"
+        f"Created function {human_readable_name} with external id {function_name}: {file_id=}, {env_vars=}"
     )
 
     return function
@@ -246,6 +250,7 @@ def robust_create(create_function):
 
 
 def deploy_function(
+    human_readable_name,
     function_name,
     folder='.',
     handler_path='handler.py',
@@ -256,13 +261,15 @@ def deploy_function(
     Deploys a Cognite function from a folder. 
 
     Inputs:
-      - function_name: name of the function to create
+      - human_readable_name: name of the function to create
+      - function_name: external id of the function to create
       - folder: path where the source code is located
       - handler_path: path to the handler file
       - secrets: api keys or similar that should be passed to the function
     """
     f = functools.partial(
         create_function_from_folder,
+        human_readable_name,
         function_name, 
         folder, 
         handler_path, 
@@ -274,6 +281,7 @@ def deploy_function(
  
 
 def redeploy_function(
+    human_readable_name,
     function_name,
     file_id,
     description,
@@ -292,6 +300,7 @@ def redeploy_function(
     """
     f = functools.partial(
         create_function_from_file,
+        human_readable_name,
         function_name, 
         file_id, 
         description,
@@ -325,10 +334,9 @@ def get_function_metadata(function_id):
     )
     return metadata
 
-
 def call_function(function_name, data):
     """
-    Call a function deployed in CDF
+    Call a function deployed in CDF based on the external id
 
     Input:
         - function_name: (string) function's external id in CDF
@@ -353,10 +361,10 @@ def call_function(function_name, data):
     logging.debug(f"Call complete ({call.id=}, {t_proc=}): {response=}")
     return response
 
-
 def call_function_process_wrapper(function_name, data):
     """
-    Set up the cdf client and call a function. This wrapper makes it possible to call a function from an independent processess invoked by the multiprocessing library
+    Set up the cdf client and call a function based on external id. 
+    This wrapper makes it possible to call a function from an independent processess invoked by the multiprocessing library
     
     Input:
         - function_name: (string) function's external id in CDF
@@ -367,10 +375,9 @@ def call_function_process_wrapper(function_name, data):
     set_up_cdf_client(context='deploy')
     return call_function(function_name, data)
 
-
 def call_function_parallel(function_name, data, n_calls=None):
     """
-    Make parallel calls to a function deployed in CDF
+    Make parallel calls to a function deployed in CDF, based on the external id of the function
 
     Input:
         - function_name: (string) function's external id in CDF
@@ -382,7 +389,6 @@ def call_function_parallel(function_name, data, n_calls=None):
     with Pool(n_calls) as p:
         return p.map(f, data)
 
-
 def test_function(function_name, data):
     """
     Call a function with data and verify that the response's 
