@@ -7,6 +7,7 @@ from akerbp.mlops.core import logger
 
 logging=logger.get_logger(name='mlops_core')
 
+
 def get_top_folder(path):
     """
     Get the top folder of a path.
@@ -30,3 +31,10 @@ def as_import_path(file_path):
         return file_path.replace(os.sep,'.').replace('.py','')
     else:
         logging.debug(f"Empty file path -> empty import path returned")
+
+
+def confirm_prompt(question):
+    reply = None
+    while reply not in ("y", "n"):
+        reply = input(f"{question} (y/n): ").lower()
+    return (reply == "y")
